@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __GPM_BACKLIGHT_H
@@ -38,7 +38,7 @@ typedef struct GpmBacklightPrivate GpmBacklightPrivate;
 
 typedef struct
 {
-	GObject		         parent;
+	GObject			 parent;
 	GpmBacklightPrivate *priv;
 } GpmBacklight;
 
@@ -66,6 +66,8 @@ gboolean	 gpm_backlight_get_brightness		(GpmBacklight	*backlight,
 gboolean	 gpm_backlight_set_brightness		(GpmBacklight	*backlight,
 							 guint		 brightness,
 							 GError		**error);
+void		 gpm_backlight_register_dbus		(GpmBacklight 	 *backlight,
+							 GDBusConnection *connection);
 
 G_END_DECLS
 
