@@ -528,6 +528,13 @@ gpm_manager_notify (GpmManager *manager, NotifyNotification **notification_class
 	g_signal_connect (notification, "closed", G_CALLBACK (gpm_manager_notification_closed_cb), notification_class);
 	g_debug ("notification %p: %s : %s", notification, title, message);
 
+	/* non-urgent notifications are transient */
+	if (urgency != NOTIFY_URGENCY_CRITICAL) {
+		notify_notification_set_hint (notification,
+					      "transient",
+					      g_variant_new_boolean (TRUE));
+	}
+
 	/* try to show */
 	ret = notify_notification_show (notification, &error);
 	if (!ret) {
@@ -911,6 +918,14 @@ gpm_manager_lid_button_pressed (GpmManager *manager, gboolean pressed)
 		return;
 	}
 
+#if UP_CHECK_VERSION(0,9,8)
+	/* are we docked? */
+	if (up_client_get_is_docked (manager->priv->client)) {
+		g_debug ("ignoring lid closed action because we are docked");
+		return;
+	}
+#endif
+
 	if (!manager->priv->on_battery) {
 		g_debug ("Performing AC policy");
 		gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_LID_AC,
