@@ -40,8 +40,6 @@
 #include <gtk/gtk.h>
 #include <libupower-glib/upower.h>
 
-#include "egg-debug.h"
-
 #include "gpm-upower.h"
 #include "gpm-engine.h"
 #include "gpm-common.h"
@@ -123,14 +121,14 @@ gpm_tray_icon_set_icon (GpmTrayIcon *icon, GIcon *gicon)
 
 	if (gicon != NULL) {
 		filename = g_icon_to_string (gicon);
-		egg_debug ("Setting icon to %s", filename);
+		g_debug ("Setting icon to %s", filename);
 		gtk_status_icon_set_from_gicon (icon->priv->status_icon, gicon);
 
 		/* make sure that we are visible */
 		gpm_tray_icon_show (icon, TRUE);
 	} else {
 		/* remove icon */
-		egg_debug ("no icon will be displayed");
+		g_debug ("no icon will be displayed");
 
 		/* make sure that we are hidden */
 		gpm_tray_icon_show (icon, FALSE);
@@ -151,7 +149,7 @@ gpm_tray_icon_show_info_cb (GtkMenuItem *item, gpointer data)
 	object_path = g_object_get_data (G_OBJECT (item), "object-path");
 	path = g_strdup_printf ("%s/gnome-power-statistics --device %s", BINDIR, object_path);
 	if (!g_spawn_command_line_async (path, NULL))
-		egg_warning ("Couldn't execute command: %s", path);
+		g_warning ("Couldn't execute command: %s", path);
 	g_free (path);
 }
 
@@ -162,10 +160,10 @@ gpm_tray_icon_show_info_cb (GtkMenuItem *item, gpointer data)
 static void
 gpm_tray_icon_show_preferences_cb (GtkMenuItem *item, gpointer data)
 {
-	const gchar *command = "gnome-power-preferences";
+	const gchar *command = "gnome-control-center power";
 
 	if (g_spawn_command_line_async (command, NULL) == FALSE)
-		egg_warning ("Couldn't execute command: %s", command);
+		g_warning ("Couldn't execute command: %s", command);
 }
 
 /**
@@ -216,7 +214,7 @@ gpm_tray_icon_add_device (GpmTrayIcon *icon, GtkMenu *menu, const GPtrArray *arr
 			continue;
 
 		object_path = up_device_get_object_path (device);
-		egg_debug ("adding device %s", object_path);
+		g_debug ("adding device %s", object_path);
 		added++;
 
 		/* generate the labels */
@@ -224,11 +222,11 @@ gpm_tray_icon_add_device (GpmTrayIcon *icon, GtkMenu *menu, const GPtrArray *arr
 		percentage_str = g_strdup_printf ("%.0f%%", percentage);
 
 		/* align title and percentage in columns */
-		hbox = gtk_hbox_new (FALSE, 3);
+		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
 		gtk_widget_show (hbox);
 
 		/* left align the device text */
-		hbox_align = gtk_hbox_new (FALSE, 0);
+		hbox_align = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_widget_show (hbox_align);
 		label_title = gtk_label_new (desc);
 		gtk_widget_show (label_title);
@@ -328,7 +326,7 @@ gpm_tray_icon_create_menu (GpmTrayIcon *icon)
 	g_ptr_array_unref (array);
 
 	/* skip for things like live-cd's and GDM */
-	if (0 && !icon->priv->show_actions)
+	if (!icon->priv->show_actions)
 		goto skip_prefs;
 
 	/* only do the seporator if we have at least one device */
@@ -361,7 +359,7 @@ static void
 gpm_tray_icon_popup_cleared_cd (GtkWidget *widget, GpmTrayIcon *icon)
 {
 	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
-	egg_debug ("clear tray");
+	g_debug ("clear tray");
 	g_object_ref_sink (widget);
 	g_object_unref (widget);
 }
@@ -396,11 +394,10 @@ gpm_tray_icon_popup_menu (GpmTrayIcon *icon, guint32 timestamp)
 static void
 gpm_tray_icon_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint32 timestamp, GpmTrayIcon *icon)
 {
-	egg_debug ("icon right clicked");
+	g_debug ("icon right clicked");
 	gpm_tray_icon_popup_menu (icon, timestamp);
 }
 
-
 /**
  * gpm_tray_icon_activate_cb:
  * @button: Which buttons are pressed
@@ -410,7 +407,7 @@ gpm_tray_icon_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint32 t
 static void
 gpm_tray_icon_activate_cb (GtkStatusIcon *status_icon, GpmTrayIcon *icon)
 {
-	egg_debug ("icon left clicked");
+	g_debug ("icon left clicked");
 	gpm_tray_icon_popup_menu (icon, gtk_get_current_event_time());
 }
 
